@@ -4,7 +4,7 @@ from typing import Any, Tuple, Dict, Iterable, Optional
 from pdkmaster.technology import (
     property_ as _prp, geometry as _geo, primitive as _prm,
 )
-from pdkmaster.design import library as _lbry
+from pdkmaster.design import circuit as _ckt, layout as _lay, library as _lbry
 
 from ..common import (
     _SRAMSpecification, _SRAMFactory, _TechCache, _FactoryCell,
@@ -42,11 +42,17 @@ class DP8TSpecification(_SRAMSpecification):
         )
 
 
-class _DP8TFactoryCell(_FactoryCell["DP8TFactory"]):
-    pass
+class _DP8TFactoryCell(_FactoryCell):
+    def __init__(self, *, name: str, fab: "DP8TFactory"):
+        super().__init__(name=name, fab=fab)
+        self._fab: "DP8TFactory"
+
+    @property
+    def fab(self) -> "DP8TFactory":
+        return self._fab
 
 
-class _DP8TCell(_BitCell["DP8TFactory"]):
+class _DP8TCell(_BitCell):
     def __init__(self, *, fab: "DP8TFactory", name: str):
         cache = fab._cache
         m2pin = cache.metalpin(2)
@@ -852,7 +858,7 @@ class _DP8TCell(_BitCell["DP8TFactory"]):
         self.set_size(width=cell_width, height=cell_height)
 
 
-class _DP8TColumn(_Column["DP8TFactory"]):
+class _DP8TColumn(_Column, _DP8TFactoryCell):
     def __init__(self, *,
         rows: int, bits: int, colmux: int,
         fab: "DP8TFactory", name: str,
@@ -1274,20 +1280,15 @@ class _DP8TBlock(_DP8TFactoryCell):
 
 
 class DP8TFactory(_SRAMFactory):
-    def __init__(self, *, lib: _lbry.Library, spec: DP8TSpecification) -> None:
-        self._lib = lib
-        self._spec = spec
+    def __init__(self, *,
+        lib: _lbry.Library, cktfab=_ckt.CircuitFactory, layoutfab=_lay.LayoutFactory,
+        spec: DP8TSpecification,
+    ) -> None:
+        super().__init__(lib=lib, cktfab=cktfab, layoutfab=layoutfab, spec=spec)
         self._cache = _TechCache(fab=self, spec=spec)
 
-    @property
-    def lib(self) -> _lbry.Library:
-        return self._lib
-    @property
-    def spec(self) -> DP8TSpecification:
-        return self._spec
-
     def bitcell(self) -> _DP8TCell:
-        return self._get_cell(cell_name="Cell", cls=_DP8TCell, cls_args={})
+        return self.getcreate_cell(name="Cell", cell_class=_DP8TCell)
 
     def wordlinedriver(self, *, wl: int) -> _WordlineDriver:
         if wl not in (1, 2):
@@ -1371,9 +1372,9 @@ class DP8TFactory(_SRAMFactory):
     def column(self, *,
         rows: int, bits: int, colmux: int,
     ) -> _DP8TColumn:
-        return self._get_cell(
-            cell_name=f"Column_{rows}R{bits}B{colmux}M",
-            cls=_DP8TColumn, cls_args={"rows": rows, "bits": bits, "colmux": colmux},
+        return self.getcreate_cell(
+            name=f"Column_{rows}R{bits}B{colmux}M",
+            cell_class=_DP8TColumn, rows=rows, bits=bits, colmux=colmux,
         )
 
     def block(self, *,
@@ -1384,9 +1385,7 @@ class DP8TFactory(_SRAMFactory):
         if cell_name is None:
             address_str = "-".join(str(bits) for bits in address_groups)
             cell_name = f"Block_{address_str}x{word_size}_{we_size}WE"
-        return self._get_cell(
-            cell_name=cell_name, cls=_DP8TBlock, cls_args={
-                "address_groups": address_groups,
-                "word_size": word_size, "we_size": we_size,
-            }
+        return self.getcreate_cell(
+            name=cell_name, cell_class=_DP8TBlock,
+            address_groups=address_groups, word_size=word_size, we_size=we_size,
         )
