@@ -1,6 +1,5 @@
 # SPDX-License-Identifier: GPL-2.0-or-later OR AGPL-3.0-or-later OR CERN-OHL-S-2.0+
-from math import floor
-from typing import Any, List, Tuple, Dict, Iterable, Optional, cast
+from typing import Any, Tuple, Dict, Iterable, Optional, cast
 
 from pdkmaster.technology import (
     property_ as _prp, geometry as _geo, primitive as _prm,
@@ -8,7 +7,7 @@ from pdkmaster.technology import (
 from pdkmaster.design import circuit as _ckt, layout as _lay, library as _lbry
 
 from ..common import (
-    _ispow2, _SRAMSpecification, _SRAMFactory, _FactoryCell,
+    _SRAMSpecification, _SRAMFactory, _FactoryCell,
     _BitCell, _WordlineDriver, _RowDecoderDrivePage, _RowDecoder, _RowPeriphery,
     _Precharge, _ColMux, _ColumnPeriphery, _Column,
 )
@@ -40,11 +39,14 @@ class SP6TSpecification(_SRAMSpecification):
             prbound=prbound,
         )
 
-class _SP6TFactoryCell(_FactoryCell["SP6TFactory"]):
-    pass
+
+class _SP6TFactoryCell(_FactoryCell):
+    def __init__(self, *, name: str, fab: "SP6TFactory"):
+        super().__init__(name=name, fab=fab)
+        self.fab: "SP6TFactory"
 
 
-class _SP6TCell(_BitCell["SP6TFactory"]):
+class _SP6TCell(_BitCell):
     def __init__(self, *, fab: "SP6TFactory", name: str):
         cache = fab._cache
         m2pin = cache.metalpin(2)
@@ -683,7 +685,7 @@ class _SP6TCell(_BitCell["SP6TFactory"]):
         self.set_size(width=cell_width, height=cell_height)
 
 
-class _SP6TColumn(_Column["SP6TFactory"]):
+class _SP6TColumn(_Column, _SP6TFactoryCell):
     def __init__(self, *,
         rows: int, bits: int, colmux: int,
         fab: "SP6TFactory", name: str,
@@ -1001,18 +1003,14 @@ class _SP6TBlock(_SP6TFactoryCell):
 
 
 class SP6TFactory(_SRAMFactory):
-    def __init__(self, *, lib: _lbry.Library, spec: SP6TSpecification):
-        super().__init__(lib=lib, spec=spec)
-
-    @property
-    def spec(self) -> SP6TSpecification:
-        return cast(SP6TSpecification, self._spec)
+    def __init__(self, *,
+        lib: _lbry.Library, cktfab=_ckt.CircuitFactory, layoutfab=_lay.LayoutFactory,
+        spec: SP6TSpecification,
+    ):
+        super().__init__(lib=lib, cktfab=cktfab, layoutfab=layoutfab, spec=spec)
 
     def bitcell(self) -> _SP6TCell:
-        return self._get_cell(
-            cell_name=f"Cell",
-            cls=_SP6TCell, cls_args={},
-        )
+        return self.getcreate_cell(name=f"Cell", cell_class=_SP6TCell)
 
     def wordlinedriver(self) -> _WordlineDriver:
         b = self.bitcell()
@@ -1065,9 +1063,9 @@ class SP6TFactory(_SRAMFactory):
     def column(self, *,
         rows: int, bits: int, colmux: int,
     ) -> _SP6TColumn:
-        return self._get_cell(
-            cell_name=f"Column_{rows}R{bits}B{colmux}M",
-            cls=_SP6TColumn, cls_args={"rows": rows, "bits": bits, "colmux": colmux},
+        return self.getcreate_cell(
+            name=f"Column_{rows}R{bits}B{colmux}M",
+            cell_class=_SP6TColumn, rows=rows, bits=bits, colmux=colmux,
         )
 
     def block(self, *,
@@ -1078,9 +1076,7 @@ class SP6TFactory(_SRAMFactory):
         if cell_name is None:
             address_str = "-".join(str(bits) for bits in address_groups)
             cell_name = f"Block_{address_str}x{word_size}_{we_size}WE"
-        return self._get_cell(
-            cell_name=cell_name, cls=_SP6TBlock, cls_args={
-                "address_groups": address_groups,
-                "word_size": word_size, "we_size": we_size,
-            }
+        return self.getcreate_cell(
+            name=cell_name, cell_class=_SP6TBlock,
+            address_groups=address_groups, word_size=word_size, we_size=we_size,
         )
